pub struct ShapeProxy { /* private fields */ }Expand description
Convex point cloud proxy used by distance, overlap, and shape-cast helpers.
Implementations
Sourceimpl ShapeProxy
impl ShapeProxy
Sourcepub fn new(points: impl Into<Vec<Vec3>>, radius: f32) -> Result<Self>
pub fn new(points: impl Into<Vec<Vec3>>, radius: f32) -> Result<Self>
Creates a proxy from support points and a non-negative radius.
Sourcepub fn capsule(
center1: impl Into<Vec3>,
center2: impl Into<Vec3>,
radius: f32,
) -> Result<Self>
pub fn capsule( center1: impl Into<Vec3>, center2: impl Into<Vec3>, radius: f32, ) -> Result<Self>
Creates a capsule proxy from two centerline points and a radius.