pub enum DebugShapeEvent {
Created(DebugShapeAsset),
Destroyed {
handle: DebugShapeHandle,
},
ClearAll,
}Expand description
Lifecycle event for persistent debug shape assets.
Variants
Created(DebugShapeAsset)
A new renderer asset should be created or refreshed.
Destroyed
A previously emitted asset should be removed from renderer caches.
Fields

handle: DebugShapeHandleRetired handle.
ClearAll
The owning world has invalidated every debug handle.