Module query

Module query 

World, body, shape, and tree query result types.

Structs

BodyCastHit
Hit reported by a body-scoped cast.
BodyClosestPoint
Closest point result for a body-scoped query.
MoverPlane
Contact plane gathered for a capsule character mover.
QueryFilter
Collision filter applied to world queries and casts.
QueryHit
Shape reported by an overlap query.
RayClosestHit
Closest hit reported by World::cast_ray_closest.
RayHit
Hit reported by a ray or shape cast callback.
ShapeRayHit
Result returned by a ray cast against a single shape.
TreeStats
Broad-phase traversal statistics returned by Box3D queries.