Quat

Struct Quat 

#[repr(C)]
pub struct Quat { pub v: Vec3, pub s: f32, }
Quaternion with vector part v and scalar part s.

Fields

v: Vec3

Vector component.

s: f32

Scalar component.

Implementations

Source

impl Quat

pub const IDENTITY: Self

Identity rotation.

pub const fn new(v: Vec3, s: f32) -> Self

Creates a quaternion from vector and scalar parts.

pub const fn from_raw(raw: b3Quat) -> Self

Converts a raw Box3D quaternion into the Rust value type.

pub const fn into_raw(self) -> b3Quat

Converts this value into the raw Box3D representation.

pub fn is_valid(self) -> bool

Returns whether this quaternion is valid according to Box3D.

pub fn validate(self) -> Result<Self>

Returns this quaternion or Error::InvalidArgument if it is invalid.

pub fn from_matrix(matrix: Matrix3) -> Result<Self>

Builds a quaternion from a valid 3x3 rotation matrix.

pub fn between_unit_vectors( v1: impl Into<Vec3>, v2: impl Into<Vec3>, ) -> Result<Self>

Computes the rotation between two unit vectors.