BoxHull

Struct BoxHull 

pub struct BoxHull { /* private fields */ }
Convex hull data for box-shaped hulls generated by Box3D.

Implementations

Source

impl BoxHull

pub fn cube(half_width: f32) -> Self

Creates an axis-aligned cube hull from a positive half-width.

pub fn new(hx: f32, hy: f32, hz: f32) -> Self

Creates an axis-aligned box hull from positive half-widths.

pub fn offset(hx: f32, hy: f32, hz: f32, offset: impl Into<Vec3>) -> Self

Creates an axis-aligned box hull offset from the local origin.

pub fn transformed(hx: f32, hy: f32, hz: f32, transform: Transform) -> Self

Creates a box hull with a local transform baked into the hull data.

pub fn scaled( half_widths: impl Into<Vec3>, transform: Transform, post_scale: impl Into<Vec3>, ) -> Self

Creates a box hull after applying a post scale.

pub fn scale_box( half_widths: impl Into<Vec3>, transform: Transform, post_scale: impl Into<Vec3>, min_half_width: f32, ) -> Result<ScaledBox>

Scales box half-widths and transform while preserving a minimum half-width.

pub const fn raw(&self) -> &b3BoxHull

Returns the raw Box3D box hull.

pub const fn hull_data(&self) -> &b3HullData

Returns the hull portion of the box hull data.